@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "posframe" "1.5.1"
+(define-package "posframe" "20251119.52"
   "Pop a posframe (just a frame) at point."
   '((emacs "26.1"))
   :url "https://github.com/tumashu/posframe"
-  :commit "4fc893c3c9ea3f6b5099ac1b369abb3c6da40b1e"
-  :revdesc "4fc893c3c9ea"
+  :commit "ec5901e75af20bf7ddb383b318b7db4d63dbaa3b"
+  :revdesc "ec5901e75af2"
   :keywords '("convenience" "tooltip")
   :authors '(("Feng Shu" . "tumashu@163.com"))
   :maintainers '(("Feng Shu" . "tumashu@163.com")))
